% Intrinsic and Extrinsic Camera Parameters
%
% This script file can be directly excecuted under Matlab to recover the camera intrinsic and extrinsic parameters.
% IMPORTANT: This file contains neither the structure of the calibration objects nor the image coordinates of the calibration points.
%            All those complementary variables are saved in the complete matlab data file Calib_Results.mat.
% For more information regarding the calibration model visit http://www.vision.caltech.edu/bouguetj/calib_doc/


%-- Focal length:
fc = [ 1114.104612528186635 ; 1115.048736071857547 ];

%-- Principal point:
cc = [ 509.453474507920873 ; 509.498349271098959 ];

%-- Skew coefficient:
alpha_c = 0.000000000000000;

%-- Distortion coefficients:
kc = [ -0.102515257170843 ; 0.112375983143232 ; 0.000044307291010 ; -0.003623927563337 ; 0.000000000000000 ];

%-- Focal length uncertainty:
fc_error = [ 3.941930992429142 ; 3.961284825687688 ];

%-- Principal point uncertainty:
cc_error = [ 4.403687107672836 ; 3.531629212914867 ];

%-- Skew coefficient uncertainty:
alpha_c_error = 0.000000000000000;

%-- Distortion coefficients uncertainty:
kc_error = [ 0.009951707672410 ; 0.049628886849801 ; 0.000828620701541 ; 0.000881294055026 ; 0.000000000000000 ];

%-- Image size:
nx = 1004;
ny = 1004;


%-- Various other variables (may be ignored if you do not use the Matlab Calibration Toolbox):
%-- Those variables are used to control which intrinsic parameters should be optimized

n_ima = 1;						% Number of calibration images
est_fc = [ 1 ; 1 ];					% Estimation indicator of the two focal variables
est_aspect_ratio = 1;				% Estimation indicator of the aspect ratio fc(2)/fc(1)
center_optim = 1;					% Estimation indicator of the principal point
est_alpha = 0;						% Estimation indicator of the skew coefficient
est_dist = [ 1 ; 1 ; 1 ; 1 ; 0 ];	% Estimation indicator of the distortion coefficients


%-- Extrinsic parameters:
%-- The rotation (omc_kk) and the translation (Tc_kk) vectors for every calibration image and their uncertainties

%-- Image #1:
omc_1 = [ -1.684641e+00 ; 3.425855e-01 ; -2.186600e+00 ];
Tc_1  = [ -3.918465e+02 ; 1.062914e+03 ; 3.026572e+03 ];
omc_error_1 = [ 4.744912e-03 ; 6.590946e-04 ; 6.846777e-03 ];
Tc_error_1  = [ 4.310752e+00 ; 3.447022e+00 ; 4.038187e+00 ];

