% Intrinsic and Extrinsic Camera Parameters
%
% This script file can be directly excecuted under Matlab to recover the camera intrinsic and extrinsic parameters.
% IMPORTANT: This file contains neither the structure of the calibration objects nor the image coordinates of the calibration points.
%            All those complementary variables are saved in the complete matlab data file Calib_Results.mat.
% For more information regarding the calibration model visit http://www.vision.caltech.edu/bouguetj/calib_doc/


%-- Focal length:
fc = [ 1125.638124904545293 ; 1128.036056175335489 ];

%-- Principal point:
cc = [ 444.045482059964684 ; 510.751154602069505 ];

%-- Skew coefficient:
alpha_c = 0.000000000000000;

%-- Distortion coefficients:
kc = [ -0.122224999309533 ; 0.116103834433563 ; 0.002637361116101 ; -0.006213978960206 ; 0.000000000000000 ];

%-- Focal length uncertainty:
fc_error = [ 5.105959084340527 ; 5.128326724758564 ];

%-- Principal point uncertainty:
cc_error = [ 6.502004828710384 ; 5.045734465129925 ];

%-- Skew coefficient uncertainty:
alpha_c_error = 0.000000000000000;

%-- Distortion coefficients uncertainty:
kc_error = [ 0.019488588579297 ; 0.138499976297921 ; 0.001178027623984 ; 0.001350252746025 ; 0.000000000000000 ];

%-- Image size:
nx = 1004;
ny = 1004;


%-- Various other variables (may be ignored if you do not use the Matlab Calibration Toolbox):
%-- Those variables are used to control which intrinsic parameters should be optimized

n_ima = 1;						% Number of calibration images
est_fc = [ 1 ; 1 ];					% Estimation indicator of the two focal variables
est_aspect_ratio = 1;				% Estimation indicator of the aspect ratio fc(2)/fc(1)
center_optim = 1;					% Estimation indicator of the principal point
est_alpha = 0;						% Estimation indicator of the skew coefficient
est_dist = [ 1 ; 1 ; 1 ; 1 ; 0 ];	% Estimation indicator of the distortion coefficients


%-- Extrinsic parameters:
%-- The rotation (omc_kk) and the translation (Tc_kk) vectors for every calibration image and their uncertainties

%-- Image #1:
omc_1 = [ -1.045475e+00 ; 7.645925e-01 ; -2.772381e+00 ];
Tc_1  = [ 7.271406e+02 ; 1.023142e+03 ; 2.679352e+03 ];
omc_error_1 = [ 6.597156e-03 ; 6.466864e-03 ; 1.473304e-02 ];
Tc_error_1  = [ 7.968973e+00 ; 6.156228e+00 ; 6.681634e+00 ];

